=======
History
=======

0.1.5 (2019-12-19)
------------------

* Updated docs and requirements
* Added script osc_to_csv
* Support for numpy array as timeseries

0.1.2 (2019-07-04)
------------------

* First release on PyPI.
* Read the docs

